package com.logotet.tablereporter;

import javax.swing.*;
import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.print.Book;
import java.awt.print.PageFormat;
import java.awt.print.PrinterJob;

/**
 * Demo showing a simple usage of JTableReporter
 */
public class DemoApp extends JPanel {
    private JTable table;
    private JButton printButton;
    private PrinterJob job;
    private PageFormat pageFormat;

    public DemoApp() {
        setLayout(new BorderLayout());
        DemoTableModel pm = new DemoTableModel();
        table = new JTable(pm);
        table.setShowHorizontalLines(false);
        table.setPreferredScrollableViewportSize(new Dimension(600, 150));
        printButton = new JButton("Print");
        JScrollPane scrollpane = new JScrollPane(table);
        add(scrollpane, BorderLayout.CENTER);
        add(printButton, BorderLayout.SOUTH);
        printButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                job = PrinterJob.getPrinterJob();
                pageFormat = job.defaultPage();
                pageFormat.setOrientation(PageFormat.PORTRAIT);

                JTableReporter tp = new JTableReporter(table, pageFormat);
                tp.setDecimalDigits(2);
                tp.setColoredRows(true);
                tp.setDatePattern("MM-dd-yyyy");
                tp.setReportFont(new Font("Times New Roman", Font.PLAIN, 10));
                tp.setCheckMark(true);
                tp.setGrid(false);
                tp.setPageText("This is the page no.");
                Book book = tp.getPageable();
                job.setPageable(book);
                if (job.printDialog()) {
// Print the job if the user didn't cancel printing
                    try {
                        job.print();
                    } catch (Exception pe) {
                        pe.printStackTrace();
                    }
                }
            }
        });
    }

    public static void main(String[] args) {
        JFrame.setDefaultLookAndFeelDecorated(true);
        JDialog.setDefaultLookAndFeelDecorated(true);
        JFrame f = new JFrame();
        f.setTitle("JTableReporter DemoApp");
        f.setSize(new Dimension(400, 200));
        f.setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
        f.getContentPane().add(new DemoApp());
        f.setVisible(true);
    }
}